Tools
=====

scifigextract
-------------

List filepath in \includegraphics[]{} commands from a tex file.

.. code-block:: sh

    scifigextract.py list mytexfile.tex

    pdf/fig1.pdf
    pdf/fig2.pdf
    pdf/fig3a.pdf
    pdf/fig3b.pdf
